History
=======


1.1.0 (2018-07-08)
------------------

* Now uses importlib_ressources for faster startup from CLI.
* Updated the command line usability.
* Added Type Annotation compliant with PEP 561.
* Updated Documentation.


1.0.5 (2018-07-06)
------------------

* Updated Documentation.
* Translated the documentation in French, Spanish, Italian, German, Italian, Japanese and Chinese.
* More detailed updates to the po files meta-data.


1.0.0 (2018-07-05)
------------------

* First release candidate.
* Added Command Line Interface.


0.1.0 (2018-06-27)
------------------

* First release on PyPI.
